#
# spec file for package tlpui
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3
Name:           tlpui
Version:        1.7.1
Release:        1.3
Summary:        A GTK user interface for TLP
License:        CC-BY-SA-4.0 AND GPL-2.0-or-later
URL:            https://github.com/d4nj1/TLPUI
Source0:        %{url}/archive/refs/tags/%{name}-%{version}.tar.gz
Source1:        %{name}.rpmlintrc
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  polkit
BuildRequires:  python3
BuildRequires:  python3-pip
BuildRequires:  python3-poetry
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
BuildRequires:  update-desktop-files
Requires:       python3-PyYAML
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       tlp
BuildArch:      noarch

%description
TLPUI is a GTK user interface for TLP written in Python. The Python scripts in
this project generate a GTK-UI to change TLP configuration files easily. It has
the aim to protect users from setting bad configuration and to deliver a basic
overview of all the valid configuration values.

%prep
%autosetup -p1 -n TLPUI-%{name}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install

sed -i "1{/^#!\/usr\/bin\/env python3/d}" %{buildroot}%{python3_sitelib}/%{name}/__main__.py
chmod -x %{buildroot}%{python3_sitelib}/%{name}/__main__.py

# Link app icon to hicolor icon dir
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
ln -s %{python3_sitelib}/%{name}/icons/themeable/hicolor/scalable/apps/tlpui.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/

# Install desktop file
%suse_update_desktop_file -i tlpui

%fdupes %{buildroot}%{python3_sitelib}/%{name}/

%check

%files
%license COPYING.md LICENSE.md
%doc README.md
%{_bindir}/*
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_datadir}/applications/*.desktop
%{python3_sitelib}/%{name}/
%{python3_sitelib}/tlp_ui-%{version}*.*-info/

%changelog
* Mon Oct  7 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.7.1:
  * Add support for TLP 1.7 release version (gh#d4nj1/TLPUI#157).
  * Obsolete python 3.8.
- Drop tlpui-application-name-fix.patch: upstreamed.
* Sun Apr 14 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add tlpui-application-name-fix.patch: Align application name
  with .desktop filename for correct icons in desktop overviews
  (gh#d4nj1/TLPUI#149); patch sent upstream.
* Tue Apr  9 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.5:
  * Fix loading css for GTK greater 4.12 (gh#d4nj1/TLPUI#147).
  * Improve appdata content.
- Add empty %%check section.
* Fri Feb  2 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.4:
  * Remove toml dependency and optimize appdata.xml
    (gh#d4nj1/TLPUI#143).
- Add tlpui.rpmlintrc file to avoid "file-not-in-%%lang" warnings.
- Drop tlui-policy and associated pkexec commands from spec file:
  now handled natively by upstream.
* Wed Nov 22 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.1:
  * Updated translations.
- Changes from version 1.6.0:
  * Compatibility with TLP 1.6.
  * Updated translations.
* Mon Jun 26 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.0-7:
  * No release notes.
* Fri Aug  5 2022 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
- Add polkit policy file tlpui.policy.
